RGBDFromRosTopic {#master}
--------------------------

### Devices

#### `RGBDFromRosTopic`

* Added new device `RGBDFromRosTopic`.
* It can be wrapped by `RGBDSSensorWrapper` to make RGBD data, collected by a ROS device, available on Yarp via `RGBDSensorClient`
